# alabi

#### *Active Learning Accelerated Bayesian Inference (ALABI)*

<p>
<a href="https://github.com/jbirky/alabi">
<img src="https://img.shields.io/badge/GitHub-jbirky3%2Falabi-blue.svg?style=flat"></a>
<a href="https://jbirky.github.io/alabi/build/index.html">
<img src="https://img.shields.io/badge/Docs-Read%20the%20docs-blue"></a>
</p>

### Authors:
- [Jessica Birky (@jbirky)](https://github.com/jbirky)
- [David Fleming (@dflemin3)](https://github.com/dflemin3)
- [Rory Barnes (@RoryBarnes)](https://github.com/RoryBarnes)
